@@ -23,7 +23,7 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA  02111-1307  USA
  *
- * $Id: scim_rawcode_imengine.h,v 1.5 2005/01/13 14:54:21 suzhe Exp $
+ * $Id: scim_rawcode_imengine.h,v 1.5.4.3 2006/01/12 07:00:36 suzhe Exp $
  */
 
 #if !defined (__SCIM_RAWCODE_IMENGINE_H)
@@ -33,13 +33,10 @@ using namespace scim;
 
 class RawCodeFactory : public IMEngineFactoryBase
 {
-    WideString m_name;
-
     friend class RawCodeInstance;
 
 public:
     RawCodeFactory ();
-    RawCodeFactory (const WideString & name, const String & languages);
     virtual ~RawCodeFactory ();
 
     virtual WideString  get_name () const;
@@ -58,20 +55,18 @@ private:
 
 class RawCodeInstance : public IMEngineInstanceBase
 {
-    Pointer <RawCodeFactory> m_factory;
+    Pointer <RawCodeFactory>    m_factory;
 
-    CommonLookupTable m_lookup_table;
-    WideString        m_preedit_string;
+    CommonLookupTable           m_lookup_table;
+    std::vector<WideString>     m_lookup_table_labels;
+    WideString                  m_preedit_string;
+    String                      m_working_encoding;
+    bool                        m_unicode;
 
-    Property          m_status_property;
+    size_t                      m_max_preedit_len;
 
-    bool              m_unicode;
-    bool              m_forward;
-    bool              m_focused;
-
-    unsigned int      m_max_preedit_len;
-
-    IConvert m_iconv;
+    IConvert                    m_working_iconv;
+    IConvert                    m_client_iconv;
 
 public:
     RawCodeInstance (RawCodeFactory *factory,
@@ -91,11 +86,13 @@ public:
     virtual void trigger_property (const String &property);
 
 private:
-    int create_lookup_table (int start = 0);
+    int create_lookup_table ();
     void process_preedit_string ();
 
     void initialize_properties ();
-    void refresh_status_property ();
+    void refresh_encoding_property ();
+
+    void set_working_encoding (const String &encoding);
 
     String get_multibyte_string (const WideString& preedit);
     ucs4_t get_unicode_value (const WideString& preedit);
