@@ -306,7 +306,11 @@ create_setup_window ()
 #endif
 
         // Create the toplevel box.
+#if GTK_CHECK_VERSION(3, 2, 0)
+        window = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+#else
         window = gtk_vbox_new (FALSE, 0);
+#endif
         gtk_widget_show (window);
 
         frame = gtk_frame_new (_("Options"));
@@ -314,13 +318,21 @@ create_setup_window ()
         gtk_container_set_border_width (GTK_CONTAINER (frame), 4);
         gtk_box_pack_start (GTK_BOX (window), frame, FALSE, FALSE, 0);
 
+#if GTK_CHECK_VERSION(3, 2, 0)
+        vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 4);
+#else
         vbox = gtk_vbox_new (FALSE, 4);
+#endif
         gtk_widget_show (vbox);
         gtk_container_set_border_width (GTK_CONTAINER (vbox), 4);
         gtk_container_add (GTK_CONTAINER (frame), vbox);
 
         // Keyboard Layout.
+#if GTK_CHECK_VERSION(3, 2, 0)
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
+#else
         hbox = gtk_hbox_new (FALSE, 4);
+#endif
         gtk_widget_show (hbox);
         gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
  
