@@ -43,7 +43,9 @@ ConfigPointer   config;
 
 void signalhandler(int sig)
 {
-    config->flush ();
+    if (config != NULL) {
+        config->flush ();
+    }
 
     std::cerr << "SCIM successfully exited.\n";
 
@@ -159,7 +161,7 @@ int main (int argc, char *argv [])
     } //End of command line parsing.
 
     // Construct new argv array for FrontEnd.
-    new_argv [new_argc ++] = "-c";
+    new_argv [new_argc ++] = const_cast <char *> ("-c");
     new_argv [new_argc ++] = const_cast <char *> (config_name.c_str ());
 
     // Store the rest argvs into new_argv.
